@@ -11,13 +11,13 @@ from . utilities import get_fmts, pprint, pprint_ex, ft, \
     make_ceder_netter, make_mosaic_figure, nice_multiple, \
     style_df, logger_level, friendly, \
     FigureManager, tweedie_convert, tweedie_density,\
-    power_variance_family, \
     iman_conover, rearrangement_algorithm_max_VaR, \
     mu_sigma_from_mean_cv, \
     make_corr_matrix, random_corr_matrix, \
     LoggerManager, knobble_fonts, approximate_work, \
     partial_e, partial_e_numeric, moms_analytic, qd, \
-    sEngFormatter, mv, picks_work, GCN, lognorm_approx
+    sEngFormatter, mv, picks_work, GCN, lognorm_approx, \
+    integral_by_doubling
 from . spectral import Distortion
 from . distributions import Frequency, Severity, Aggregate
 from . portfolio import Portfolio, make_awkward
@@ -25,6 +25,14 @@ from . underwriter import Underwriter, build, debug_build
 from . bounds import Bounds, plot_max_min, plot_lee
 from . constants import *
 
+import sys
+
+# knobble warnings
+# https://docs.python.org/3/library/warnings.html#temporarily-suppressing-warnings
+if not sys.warnoptions:
+    import warnings
+    warnings.simplefilter("ignore")
+
 
 __docformat__ = 'restructuredtext'
 __project__ = 'aggregate'
@@ -34,7 +42,7 @@ __license__ = "BSD 3-Clause New License"
 __email__ = "steve@convexrisk.com"
 __status__ = "alpha"
 # only need to change here, feeds conf.py (docs) and setup.py (build)
-__version__ = "0.9.6.5"
+__version__ = "0.10.0"
 
 # set up
 from pathlib import Path
@@ -57,10 +65,5 @@ knobble_fonts()
 
 # module level doc-string
 __doc__ = """
-**aggregate** is a Python package providing an expressive language and fast, accurate computations
-to make working with aggregate (compound) probability distributions
-easy and intuitive. It allows students and practitioners to work with realistic
-real-world distributions that reflect the underlying frequency and severity
-generating processes. It has applications in insurance, risk management, actuarial
-science, and related areas.
+:mod:`aggregate` solves insurance, risk management, and actuarial problems using realistic models that reflect underlying frequency and severity. It makes working with an aggregate (compound) probability distribution as easy as the lognormal, delivering the speed and accuracy of parametric distributions to situations that usually require simulation. :mod:`aggregate` includes an expressive language called DecL to describe aggregate distributions and is implemented in Python under an open source BSD-license.
 """
