@@ -102,6 +102,7 @@ class Distortion(object):
         self.col_x = col_x
         self.col_y = col_y
         self.display_name = display_name
+        g_prime = None
 
         # now make g and g_inv
         if self._name == 'ph':
@@ -116,6 +117,9 @@ class Distortion(object):
             def g_inv(x):
                 return x ** rhoinv
 
+            def g_prime(x):
+                return rho * x ** (rho - 1.0) if x > 0 else np.inf
+
         elif self._name == 'wang':
             lam = self.shape
             n = ss.norm()
@@ -127,6 +131,9 @@ class Distortion(object):
             def g_inv(x):
                 return n.cdf(n.ppf(x) - lam)
 
+            def g_prime(x):
+                return n.pdf(n.ppf(x) - lam) / n.pdf(n.ppf(x) + lam)
+
         elif self._name == 'tt':
             lam = self.shape
             t = ss.t(self.df)
@@ -163,6 +170,9 @@ class Distortion(object):
             def g_inv(x):
                 return np.where(x < 1, x * (1 - p), 1)
 
+            def g_prime(x):
+                return np.where(x < 1 - p, alpha, 0)
+
         elif self._name == 'ly':
             # linear yield
             # r0 = occupancy; rk = consumption specified in list shape parameter
@@ -205,6 +215,9 @@ class Distortion(object):
             def g_inv(x):
                 return np.where(x <= d, 0, (x - d) / v)
 
+            def g_prime(x):
+                return v
+
         elif self._name == 'lep':
             # leverage equivalent pricing
             # self.r0 = risk free/financing and r = risk charge (the solved parameter)
@@ -241,6 +254,9 @@ class Distortion(object):
             def g_inv(y):
                 return 1 - (1 - y)**q
 
+            def g_prime(x):
+                return p * (1 - x)**(p - 1)
+
         elif self._name == 'wtdtvar' or self._name == 'bitvar':
             # weighted tvar, df = p0 <p1, shape = weight on p1
             try:
@@ -293,11 +309,15 @@ class Distortion(object):
 
         self.g = g
         self.g_inv = g_inv
+        if g_prime is None:
+            g_prime = lambda x: (g(x + 1e-6) - g(x - 1e-6)) / 2e-6
+        self.g_prime = g_prime
 
-        def g_dual(x):
-            return 1 - self.g(x)
-
-        self.g_dual = g_dual
+    def g_dual(self, x):
+        """
+        The dual of the distortion function g.
+        """
+        return 1 - self.g(1 - x)
 
     def __str__(self):
         if self.display_name != '':
@@ -618,3 +638,104 @@ class Distortion(object):
         return Distortion('convex', None, df=pd.DataFrame({'s': s.flat, 'gs': gs.flat}),
                           col_x='s', col_y='gs', display_name=display_name)
 
+    def price(self, ser, a=np.inf, kind='ask', S_calculation='forwards'):
+        r"""
+        Compute the bid and ask prices for the distribution determined by ``ser`` with
+        an asset limit ``a``. Index of ``ser`` need not be equally spaced, so it can
+        be applied to :math:`\kappa`. To do this for unit A in portfolio port::
+
+            ser = port.density_df[['exeqa_A', 'p_total']].\
+                set_index('exeqa_A').groupby('exeqa_A').\
+                sum()['p_total']
+            dist.price(ser, port.q(0.99), 'both')
+
+
+        :param ser: pd.Series of is probabilities, indexed by outcomes. Outcomes must
+          be spaced evenly. ``ser`` is usually a probability column from ``density_df``.
+        :param kind: is "ask", "bid",  or "both", giving the pricing view.
+        :param a: asset level. ``ser`` is truncated at ``a``.
+        """
+
+        if not isinstance(ser, pd.Series):
+            raise ValueError(f'ser must be a pandas Series, not {type(ser)}')
+
+        if kind in ['bid', 'ask']:
+            pass
+        elif kind == 'both':
+            return [*self.price(ser, a, 'bid', S_calculation),
+                    self.price(ser, a, 'ask', S_calculation)[0]]
+        else:
+            raise ValueError(f'kind must be bid, ask, or both, not {kind}')
+
+        # apply limit
+        if a < np.inf:
+            ser = ser.copy()
+            tail = ser[a:].sum()
+            ser = ser[:a]
+            ser[a] = tail
+        else:
+            ser = ser.sort_index(ascending=True)
+
+        if S_calculation == 'forwards':
+            S = 1 - ser.cumsum()
+            S = np.maximum(0, S)
+        else:
+            fill_value = max(0, 1 - ser.sum())
+            S = np.minimum(1, fill_value +
+                           ser.shift(-1, fill_value=0)[::-1].cumsum()[::-1])
+
+        # not all distortions return numpy; force conversion
+        if kind == 'ask':
+            gS = np.array(self.g(S))
+        else:
+            gS = np.array(self.g_dual(S))
+
+        # trapz is not correct with our interpretation elsewhere; we use a step function
+        # loss = np.trapz(S, S.index)
+        # prem = np.trapz(gS, S.index)
+        dx = np.diff(S.index)
+        loss = (S.iloc[:-1].values * dx).sum()
+        prem = (gS[:-1] * dx).sum()
+        return prem, loss
+
+    def price2(self, ser, a=None, S_calculation='forwards'):
+        r"""
+        Compute the bid and ask prices for the distribution determined by ``ser`` with
+        an asset limits given by values of ``ser``. Index of ``ser`` need not be equally
+        spaced, so it can be applied to :math:`\kappa`. To do this for unit A in portfolio
+        ``port``::
+
+            ser = port.density_df[['exeqa_A', 'p_total']].\
+                set_index('exeqa_A').groupby('exeqa_A').\
+                sum()['p_total']
+            dist.price(ser, port.q(0.99))
+
+        :param ser: pd.Series of is probabilities, indexed by outcomes. Outcomes must
+          be spaced evenly. ``ser`` is usually a probability column from ``density_df``.
+        """
+
+        if not isinstance(ser, pd.Series):
+            raise ValueError(f'ser must be a pandas Series, not {type(ser)}')
+
+        if S_calculation == 'forwards':
+            S = 1 - ser.cumsum()
+            S = np.maximum(0, S)
+        else:
+            fill_value = max(0, 1 - ser.sum())
+            S = np.minimum(1, fill_value +
+                           ser.shift(-1, fill_value=0)[::-1].cumsum()[::-1])
+
+        # not all distortions return numpy; force conversion
+        gS = np.array(self.g(S))
+        dgS = np.array(self.g_dual(S))
+
+        dx = np.diff(S.index)
+        loss = (S.iloc[:-1].values * dx).cumsum()
+        ask = (gS[:-1] * dx).cumsum()
+        bid = (dgS[:-1] * dx).cumsum()
+        ans = pd.DataFrame({'bid': bid, 'el': loss, 'ask': ask}, index=S.index[1:])
+        if a is None:
+            return ans
+        else:
+            # no longer guaranteed that a is in ser.index
+            return ans.iloc[ans.index.get_loc(a, method='nearest')]
\ No newline at end of file
