@@ -7,6 +7,7 @@ import re
 from IPython.display import HTML, display
 # from inspect import signature
 
+from .constants import *
 from .portfolio import Portfolio
 from .distributions import Aggregate, Severity
 from .spectral import Distortion
@@ -82,6 +83,11 @@ class Underwriter(object):
         # check site dir exists
         self.site_dir.mkdir(parents=True, exist_ok=True)
 
+        # case dir
+        self.case_dir = Path.home() / 'aggregate/cases'
+        # check case dir exists
+        self.case_dir.mkdir(parents=True, exist_ok=True)
+
         self.template_dir = self.default_dir.parent / 'templates'
         self.template_dir.mkdir(parents=True, exist_ok=True)
 
@@ -190,8 +196,8 @@ class Underwriter(object):
 
     def __repr__(self):
         s = []
-        s.append(f'Underwriter   {self.name}')
-        s.append(f'Knowledge     {len(self._knowledge)} programs')
+        s.append(f'underwriter   {self.name}')
+        s.append(f'knowledge     {len(self._knowledge)} programs')
         for k in ['log2', 'update', 'debug', 'site_dir', 'default_dir']:
             s.append(f'{k:<14s}{getattr(self, k)}')
         # s.append(super().__repr__())
@@ -239,7 +245,7 @@ class Underwriter(object):
             obj.program = program
         elif kind == 'sev':
             if 'sev_wt' in spec and spec['sev_wt'] != 1:
-                logger.warning(
+                logger.log(WL,
                     f'Mixed severity cannot be created, returning spec. You had {spec["sev_wt"]}, expected 1')
                 obj = None
             else:
@@ -339,7 +345,7 @@ class Underwriter(object):
 
         # report on what has been done
         if rv is None:
-            logger.warning(f'Program did not contain any output')
+            logger.log(WL, f'Program did not contain any output')
         else:
             if len(rv):
                 logger.info(f'Program created {len(rv)} objects.')
@@ -507,7 +513,7 @@ class Underwriter(object):
         rv = self.write(program, update=False, force_severity=True)
 
         if rv is None or len(rv) == 0:
-            logger.warning('build produced no output')
+            logger.log(WL, 'build produced no output')
             return None
 
         # in this loop bs_ and log2_ are the values actually used for each update;
@@ -527,6 +533,9 @@ class Underwriter(object):
                         max_loss = np.max(d['sev_xs']) * d['exp_en']
                     elif d['freq_name'] == 'empirical':
                         max_loss = np.max(d['sev_xs']) * max(d['freq_a'])
+                    elif d['freq_name'] == 'bernoulli':
+                        # allow for max loss to occur
+                        max_loss = np.max(d['sev_xs'])
                     else:
                         # normal approx on count
                         max_loss = np.max(d['sev_xs']) * d['exp_en'] * (1 + 3 * d['exp_en'] ** 0.5)
@@ -841,107 +850,6 @@ class Underwriter(object):
         ans = pd.DataFrame(entries, columns=['Directory', 'Database', 'kind', 'name'])
         return ans
 
-    # def list(self, regex='', kind=''):
-    #     """
-    #     Not sure what the best name is!
-    #     """
-    #
-    #     # catch called with kind = these seem to work...
-    #     if regex in ('agg', 'port', 'sev'):
-    #         kind = regex
-    #         regex = ''
-    #
-    #     if regex == '' and kind == '':
-    #         return self.knowledge
-    #     elif kind == '':
-    #         return self.knowledge.filter(regex=regex, axis=0)
-    #     elif regex == '':
-    #         return self.knowledge.loc[kind]
-    #     else:
-    #         return self.knowledge.loc[kind].filter(regex=regex, axis=0)
-
-    # def describe(self, kind='agg'):
-    #     """
-    #     TODO this is not rationlized...and as a prop it needs to return something
-    #     More informative version of knowledge showing the agg programs. Only Aggregates that have a program.
-    #
-    #     TODO Add severities
-    #
-    #     :return:
-    #     """
-    #     from IPython.display import HTML
-    #
-    #     if kind == 'all':
-    #         kinds = ['agg', 'port']
-    #     else:
-    #         kinds = [kind]
-    #
-    #     if 'port' in kinds:
-    #         cols = ['Name', 'Type', 'Agg1', 'Agg2', 'Agg3', 'Notes']
-    #         df_port = pd.DataFrame(columns=cols)
-    #         df_port = df_port.set_index('Name')
-    #         for (kind, name), (spec, program) in self._knowledge.xs('port', axis=0, level=0,
-    #                                                                 drop_level=False).iterrows():
-    #             aggs = spec['spec'][:3]  # the list of agg items
-    #             if len(aggs) == 1:
-    #                 aggs.extend(['', ''])
-    #             elif len(aggs) == 2:
-    #                 aggs.extend([''])
-    #             note = spec['note']
-    #             df_port.loc[name, :] = [kind] + aggs + [note]
-    #         df_port = df_port.sort_index()
-    #         return df_port
-    #         # display(HTML('<h3>Known Portfolios</h3>'))
-    #         # display(df_port)
-    #
-    #     if 'agg' in kinds:
-    #         cols = ['Name', 'Type', 'ELoss', 'Severity', 'ESev', 'SevCV', 'Sev_a', 'Sev_b', 'Freq', 'EN', 'Freq_a',
-    #                 'Notes']
-    #         # what they are actually called
-    #         cols_agg = ['exp_el', 'sev_name', 'sev_mean', 'sev_cv', 'sev_a', 'sev_b', 'freq_name', 'exp_en', 'freq_a',
-    #                     'note']
-    #         df_agg = pd.DataFrame(columns=cols)
-    #         df_agg = df_agg.set_index('Name')
-    #         for (kind, name), (spec, program) in self._knowledge.xs('agg', axis=0, level=0,
-    #                                                                 drop_level=False).iterrows():
-    #             df_agg.loc[name, :] = [kind] + [str(spec.get(f, '')) for f in cols_agg]
-    #         df_agg = df_agg.sort_index()
-    #         # compute E loss... but careful about arrays
-    #         # TODO must be a better way
-    #         for i in df_agg.query('ELoss == ""').index:
-    #             es, en = df_agg.loc[i, ['ESev', 'EN']]
-    #             try:
-    #                 es = float(es)
-    #                 en = float(en)
-    #             except (ValueError, TypeError):
-    #                 df_agg.loc[i, 'ELoss'] = '...'
-    #             else:
-    #                 df_agg.loc[i, 'ELoss'] = es * en
-    #
-    #         df_agg = df_agg.drop(columns='Sev_b')
-    #         return df_agg
-    #         # display(HTML('<h3>Known Aggregates</h3>'))
-    #         # display(df_agg)
-    #
-    #     if 'distortion' in kinds:
-    #         return self._knowledge.loc['distortion']
-
-    # @property
-    # def programs(self):
-    #     """
-    #     Return the knowledge as a nice dataframe
-    #
-    #     :return:
-    #     """
-    #     bit = self._knowledge[['program']]
-    #     bit['note'] = [s['note'] for s in self._knowledge.spec]
-    #     bit['clean program'] = bit.program.str.replace(r'note\{[^}]*\}|[ ]{2,}|\t+', ' ')
-    #     bit = bit.sort_index(ascending=[False, True])
-    #     bit = bit.reset_index(0, drop=False)
-    #     bit = bit[['kind', 'note', 'clean program']].query('`clean program` != ""')
-    #     bit = bit[['kind', 'clean program', 'note']]
-    #     return bit
-
 
 # exported instance
 # self = dbuild = None
